@@ -93,7 +93,7 @@ def createIndex(client, num_docs=100, definition=None):
     assert 50 == indexer.chunk_size
 
     for key, doc in chapters.items():
-        indexer.add_document(key, **doc)
+        indexer.client.client.hset(key, mapping=doc)
     indexer.commit()
 
 
@@ -107,7 +107,7 @@ def client(modclient):
 def test_client(client):
     num_docs = 500
     createIndex(client.ft(), num_docs=num_docs)
-    waitForIndex(client, "idx")
+    waitForIndex(client, getattr(client.ft(), "index_name", "idx"))
     # verify info
     info = client.ft().info()
     for k in [
@@ -196,7 +196,7 @@ def test_client(client):
     assert 167 == client.ft().search(Query("henry king").slop(100)).total
 
     # test delete document
-    client.ft().add_document("doc-5ghs2", play="Death of a Salesman")
+    client.hset("doc-5ghs2", mapping={"play": "Death of a Salesman"})
     res = client.ft().search(Query("death of a salesman"))
     assert 1 == res.total
 
@@ -205,36 +205,19 @@ def test_client(client):
     assert 0 == res.total
     assert 0 == client.ft().delete_document("doc-5ghs2")
 
-    client.ft().add_document("doc-5ghs2", play="Death of a Salesman")
+    client.hset("doc-5ghs2", mapping={"play": "Death of a Salesman"})
     res = client.ft().search(Query("death of a salesman"))
     assert 1 == res.total
     client.ft().delete_document("doc-5ghs2")
 
 
-@pytest.mark.redismod
-@skip_ifmodversion_lt("2.2.0", "search")
-def test_payloads(client):
-    client.ft().create_index((TextField("txt"),))
-
-    client.ft().add_document("doc1", payload="foo baz", txt="foo bar")
-    client.ft().add_document("doc2", txt="foo bar")
-
-    q = Query("foo bar").with_payloads()
-    res = client.ft().search(q)
-    assert 2 == res.total
-    assert "doc1" == res.docs[0].id
-    assert "doc2" == res.docs[1].id
-    assert "foo baz" == res.docs[0].payload
-    assert res.docs[1].payload is None
-
-
 @pytest.mark.redismod
 @pytest.mark.onlynoncluster
 def test_scores(client):
     client.ft().create_index((TextField("txt"),))
 
-    client.ft().add_document("doc1", txt="foo baz")
-    client.ft().add_document("doc2", txt="foo bar")
+    client.hset("doc1", mapping={"txt": "foo baz"})
+    client.hset("doc2", mapping={"txt": "foo bar"})
 
     q = Query("foo ~bar").with_scores()
     res = client.ft().search(q)
@@ -246,33 +229,12 @@ def test_scores(client):
     # self.assertEqual(0.2, res.docs[1].score)
 
 
-@pytest.mark.redismod
-def test_replace(client):
-    client.ft().create_index((TextField("txt"),))
-
-    client.ft().add_document("doc1", txt="foo bar")
-    client.ft().add_document("doc2", txt="foo bar")
-    waitForIndex(client, "idx")
-
-    res = client.ft().search("foo bar")
-    assert 2 == res.total
-    client.ft().add_document("doc1", replace=True, txt="this is a replaced doc")
-
-    res = client.ft().search("foo bar")
-    assert 1 == res.total
-    assert "doc2" == res.docs[0].id
-
-    res = client.ft().search("replaced doc")
-    assert 1 == res.total
-    assert "doc1" == res.docs[0].id
-
-
 @pytest.mark.redismod
 def test_stopwords(client):
     client.ft().create_index((TextField("txt"),), stopwords=["foo", "bar", "baz"])
-    client.ft().add_document("doc1", txt="foo bar")
-    client.ft().add_document("doc2", txt="hello world")
-    waitForIndex(client, "idx")
+    client.hset("doc1", mapping={"txt": "foo bar"})
+    client.hset("doc2", mapping={"txt": "hello world"})
+    waitForIndex(client, getattr(client.ft(), "index_name", "idx"))
 
     q1 = Query("foo bar").no_content()
     q2 = Query("foo bar hello world").no_content()
@@ -284,10 +246,12 @@ def test_stopwords(client):
 @pytest.mark.redismod
 def test_filters(client):
     client.ft().create_index((TextField("txt"), NumericField("num"), GeoField("loc")))
-    client.ft().add_document("doc1", txt="foo bar", num=3.141, loc="-0.441,51.458")
-    client.ft().add_document("doc2", txt="foo baz", num=2, loc="-0.1,51.2")
+    client.hset(
+        "doc1", mapping={"txt": "foo bar", "num": 3.141, "loc": "-0.441,51.458"}
+    )
+    client.hset("doc2", mapping={"txt": "foo baz", "num": 2, "loc": "-0.1,51.2"})
 
-    waitForIndex(client, "idx")
+    waitForIndex(client, getattr(client.ft(), "index_name", "idx"))
     # Test numerical filter
     q1 = Query("foo").add_filter(NumericFilter("num", 0, 2)).no_content()
     q2 = (
@@ -317,23 +281,12 @@ def test_filters(client):
     assert ["doc1", "doc2"] == res
 
 
-@pytest.mark.redismod
-def test_payloads_with_no_content(client):
-    client.ft().create_index((TextField("txt"),))
-    client.ft().add_document("doc1", payload="foo baz", txt="foo bar")
-    client.ft().add_document("doc2", payload="foo baz2", txt="foo bar")
-
-    q = Query("foo bar").with_payloads().no_content()
-    res = client.ft().search(q)
-    assert 2 == len(res.docs)
-
-
 @pytest.mark.redismod
 def test_sort_by(client):
     client.ft().create_index((TextField("txt"), NumericField("num", sortable=True)))
-    client.ft().add_document("doc1", txt="foo bar", num=1)
-    client.ft().add_document("doc2", txt="foo baz", num=2)
-    client.ft().add_document("doc3", txt="foo qux", num=3)
+    client.hset("doc1", mapping={"txt": "foo bar", "num": 1})
+    client.hset("doc2", mapping={"txt": "foo baz", "num": 2})
+    client.hset("doc3", mapping={"txt": "foo qux", "num": 3})
 
     # Test sort
     q1 = Query("foo").sort_by("num", asc=True).no_content()
@@ -375,10 +328,12 @@ def test_example(client):
     client.ft().create_index((TextField("title", weight=5.0), TextField("body")))
 
     # Indexing a document
-    client.ft().add_document(
+    client.hset(
         "doc1",
-        title="RediSearch",
-        body="Redisearch impements a search engine on top of redis",
+        mapping={
+            "title": "RediSearch",
+            "body": "Redisearch impements a search engine on top of redis",
+        },
     )
 
     # Searching with complex parameters:
@@ -450,13 +405,15 @@ def test_no_index(client):
         )
     )
 
-    client.ft().add_document(
-        "doc1", field="aaa", text="1", numeric="1", geo="1,1", tag="1"
+    client.hset(
+        "doc1",
+        mapping={"field": "aaa", "text": "1", "numeric": "1", "geo": "1,1", "tag": "1"},
     )
-    client.ft().add_document(
-        "doc2", field="aab", text="2", numeric="2", geo="2,2", tag="2"
+    client.hset(
+        "doc2",
+        mapping={"field": "aab", "text": "2", "numeric": "2", "geo": "2,2", "tag": "2"},
     )
-    waitForIndex(client, "idx")
+    waitForIndex(client, getattr(client.ft(), "index_name", "idx"))
 
     res = client.ft().search(Query("@text:aa*"))
     assert 0 == res.total
@@ -491,45 +448,6 @@ def test_no_index(client):
         TagField("name", no_index=True, sortable=False)
 
 
-@pytest.mark.redismod
-def test_partial(client):
-    client.ft().create_index((TextField("f1"), TextField("f2"), TextField("f3")))
-    client.ft().add_document("doc1", f1="f1_val", f2="f2_val")
-    client.ft().add_document("doc2", f1="f1_val", f2="f2_val")
-    client.ft().add_document("doc1", f3="f3_val", partial=True)
-    client.ft().add_document("doc2", f3="f3_val", replace=True)
-    waitForIndex(client, "idx")
-
-    # Search for f3 value. All documents should have it
-    res = client.ft().search("@f3:f3_val")
-    assert 2 == res.total
-
-    # Only the document updated with PARTIAL should still have f1 and f2 values
-    res = client.ft().search("@f3:f3_val @f2:f2_val @f1:f1_val")
-    assert 1 == res.total
-
-
-@pytest.mark.redismod
-def test_no_create(client):
-    client.ft().create_index((TextField("f1"), TextField("f2"), TextField("f3")))
-    client.ft().add_document("doc1", f1="f1_val", f2="f2_val")
-    client.ft().add_document("doc2", f1="f1_val", f2="f2_val")
-    client.ft().add_document("doc1", f3="f3_val", no_create=True)
-    client.ft().add_document("doc2", f3="f3_val", no_create=True, partial=True)
-    waitForIndex(client, "idx")
-
-    # Search for f3 value. All documents should have it
-    res = client.ft().search("@f3:f3_val")
-    assert 2 == res.total
-
-    # Only the document updated with PARTIAL should still have f1 and f2 values
-    res = client.ft().search("@f3:f3_val @f2:f2_val @f1:f1_val")
-    assert 1 == res.total
-
-    with pytest.raises(redis.ResponseError):
-        client.ft().add_document("doc3", f2="f2_val", f3="f3_val", no_create=True)
-
-
 @pytest.mark.redismod
 def test_explain(client):
     client.ft().create_index((TextField("f1"), TextField("f2"), TextField("f3")))
@@ -546,7 +464,7 @@ def test_explaincli(client):
 @pytest.mark.redismod
 def test_summarize(client):
     createIndex(client.ft())
-    waitForIndex(client, "idx")
+    waitForIndex(client, getattr(client.ft(), "index_name", "idx"))
 
     q = Query("king henry").paging(0, 1)
     q.highlight(fields=("play", "txt"), tags=("<b>", "</b>"))
@@ -618,11 +536,11 @@ def test_alias_basic(client):
     index1 = getClient(client).ft("testAlias")
 
     index1.create_index((TextField("txt"),))
-    index1.add_document("doc1", txt="text goes here")
+    index1.client.hset("doc1", mapping={"txt": "text goes here"})
 
     index2 = getClient(client).ft("testAlias2")
     index2.create_index((TextField("txt"),))
-    index2.add_document("doc2", txt="text goes here")
+    index2.client.hset("doc2", mapping={"txt": "text goes here"})
 
     # add the actual alias and check
     index1.aliasadd("myalias")
@@ -646,36 +564,6 @@ def test_alias_basic(client):
         _ = alias_client2.search("*").docs[0]
 
 
-@pytest.mark.redismod
-def test_tags(client):
-    client.ft().create_index((TextField("txt"), TagField("tags")))
-    tags = "foo,foo bar,hello;world"
-    tags2 = "soba,ramen"
-
-    client.ft().add_document("doc1", txt="fooz barz", tags=tags)
-    client.ft().add_document("doc2", txt="noodles", tags=tags2)
-    waitForIndex(client, "idx")
-
-    q = Query("@tags:{foo}")
-    res = client.ft().search(q)
-    assert 1 == res.total
-
-    q = Query("@tags:{foo bar}")
-    res = client.ft().search(q)
-    assert 1 == res.total
-
-    q = Query("@tags:{foo\\ bar}")
-    res = client.ft().search(q)
-    assert 1 == res.total
-
-    q = Query("@tags:{hello\\;world}")
-    res = client.ft().search(q)
-    assert 1 == res.total
-
-    q2 = client.ft().tagvals("tags")
-    assert (tags.split(",") + tags2.split(",")).sort() == q2.sort()
-
-
 @pytest.mark.redismod
 def test_textfield_sortable_nostem(client):
     # Creating the index definition with sortable and no_stem
@@ -696,8 +584,8 @@ def test_alter_schema_add(client):
     client.ft().alter_schema_add(TextField("body"))
 
     # Indexing a document
-    client.ft().add_document(
-        "doc1", title="MyTitle", body="Some content only in the body"
+    client.hset(
+        "doc1", mapping={"title": "MyTitle", "body": "Some content only in the body"}
     )
 
     # Searching with parameter only in the body (the added field)
@@ -712,9 +600,11 @@ def test_alter_schema_add(client):
 def test_spell_check(client):
     client.ft().create_index((TextField("f1"), TextField("f2")))
 
-    client.ft().add_document("doc1", f1="some valid content", f2="this is sample text")
-    client.ft().add_document("doc2", f1="very important", f2="lorem ipsum")
-    waitForIndex(client, "idx")
+    client.hset(
+        "doc1", mapping={"f1": "some valid content", "f2": "this is sample text"}
+    )
+    client.hset("doc2", mapping={"f1": "very important", "f2": "lorem ipsum"})
+    waitForIndex(client, getattr(client.ft(), "index_name", "idx"))
 
     # test spellcheck
     res = client.ft().spellcheck("impornant")
@@ -767,8 +657,8 @@ def test_dict_operations(client):
 @pytest.mark.redismod
 def test_phonetic_matcher(client):
     client.ft().create_index((TextField("name"),))
-    client.ft().add_document("doc1", name="Jon")
-    client.ft().add_document("doc2", name="John")
+    client.hset("doc1", mapping={"name": "Jon"})
+    client.hset("doc2", mapping={"name": "John"})
 
     res = client.ft().search(Query("Jon"))
     assert 1 == len(res.docs)
@@ -778,8 +668,8 @@ def test_phonetic_matcher(client):
     client.flushdb()
 
     client.ft().create_index((TextField("name", phonetic_matcher="dm:en"),))
-    client.ft().add_document("doc1", name="Jon")
-    client.ft().add_document("doc2", name="John")
+    client.hset("doc1", mapping={"name": "Jon"})
+    client.hset("doc2", mapping={"name": "John"})
 
     res = client.ft().search(Query("Jon"))
     assert 2 == len(res.docs)
@@ -791,12 +681,14 @@ def test_phonetic_matcher(client):
 def test_scorer(client):
     client.ft().create_index((TextField("description"),))
 
-    client.ft().add_document(
-        "doc1", description="The quick brown fox jumps over the lazy dog"
+    client.hset(
+        "doc1", mapping={"description": "The quick brown fox jumps over the lazy dog"}
     )
-    client.ft().add_document(
+    client.hset(
         "doc2",
-        description="Quick alice was beginning to get very tired of sitting by her quick sister on the bank, and of having nothing to do.",  # noqa
+        mapping={
+            "description": "Quick alice was beginning to get very tired of sitting by her quick sister on the bank, and of having nothing to do."  # noqa
+        },
     )
 
     # default scorer is TFIDF
@@ -823,19 +715,19 @@ def test_get(client):
     assert [None] == client.ft().get("doc1")
     assert [None, None] == client.ft().get("doc2", "doc1")
 
-    client.ft().add_document(
-        "doc1", f1="some valid content dd1", f2="this is sample text ff1"
+    client.hset(
+        "doc1", mapping={"f1": "some valid content dd1", "f2": "this is sample text f1"}
     )
-    client.ft().add_document(
-        "doc2", f1="some valid content dd2", f2="this is sample text ff2"
+    client.hset(
+        "doc2", mapping={"f1": "some valid content dd2", "f2": "this is sample text f2"}
     )
 
     assert [
-        ["f1", "some valid content dd2", "f2", "this is sample text ff2"]
+        ["f1", "some valid content dd2", "f2", "this is sample text f2"]
     ] == client.ft().get("doc2")
     assert [
-        ["f1", "some valid content dd1", "f2", "this is sample text ff1"],
-        ["f1", "some valid content dd2", "f2", "this is sample text ff2"],
+        ["f1", "some valid content dd1", "f2", "this is sample text f1"],
+        ["f1", "some valid content dd2", "f2", "this is sample text f2"],
     ] == client.ft().get("doc1", "doc2")
 
 
@@ -866,31 +758,42 @@ def test_aggregations_groupby(client):
     )
 
     # Indexing a document
-    client.ft().add_document(
+    client.hset(
         "search",
-        title="RediSearch",
-        body="Redisearch impements a search engine on top of redis",
-        parent="redis",
-        random_num=10,
+        mapping={
+            "title": "RediSearch",
+            "body": "Redisearch impements a search engine on top of redis",
+            "parent": "redis",
+            "random_num": 10,
+        },
     )
-    client.ft().add_document(
+    client.hset(
         "ai",
-        title="RedisAI",
-        body="RedisAI executes Deep Learning/Machine Learning models and managing their data.",  # noqa
-        parent="redis",
-        random_num=3,
+        mapping={
+            "title": "RedisAI",
+            "body": "RedisAI executes Deep Learning/Machine Learning models and managing their data.",  # noqa
+            "parent": "redis",
+            "random_num": 3,
+        },
     )
-    client.ft().add_document(
+    client.hset(
         "json",
-        title="RedisJson",
-        body="RedisJSON implements ECMA-404 The JSON Data Interchange Standard as a native data type.",  # noqa
-        parent="redis",
-        random_num=8,
+        mapping={
+            "title": "RedisJson",
+            "body": "RedisJSON implements ECMA-404 The JSON Data Interchange Standard as a native data type.",  # noqa
+            "parent": "redis",
+            "random_num": 8,
+        },
     )
 
+    req = aggregations.AggregateRequest("redis").group_by("@parent", reducers.count())
+
+    res = client.ft().aggregate(req).rows[0]
+    assert res[1] == "redis"
+    assert res[3] == "3"
+
     req = aggregations.AggregateRequest("redis").group_by(
-        "@parent",
-        reducers.count(),
+        "@parent", reducers.count_distinct("@title")
     )
 
     res = client.ft().aggregate(req).rows[0]
@@ -898,8 +801,7 @@ def test_aggregations_groupby(client):
     assert res[3] == "3"
 
     req = aggregations.AggregateRequest("redis").group_by(
-        "@parent",
-        reducers.count_distinct("@title"),
+        "@parent", reducers.count_distinctish("@title")
     )
 
     res = client.ft().aggregate(req).rows[0]
@@ -907,17 +809,7 @@ def test_aggregations_groupby(client):
     assert res[3] == "3"
 
     req = aggregations.AggregateRequest("redis").group_by(
-        "@parent",
-        reducers.count_distinctish("@title"),
-    )
-
-    res = client.ft().aggregate(req).rows[0]
-    assert res[1] == "redis"
-    assert res[3] == "3"
-
-    req = aggregations.AggregateRequest("redis").group_by(
-        "@parent",
-        reducers.sum("@random_num"),
+        "@parent", reducers.sum("@random_num")
     )
 
     res = client.ft().aggregate(req).rows[0]
@@ -925,8 +817,7 @@ def test_aggregations_groupby(client):
     assert res[3] == "21"  # 10+8+3
 
     req = aggregations.AggregateRequest("redis").group_by(
-        "@parent",
-        reducers.min("@random_num"),
+        "@parent", reducers.min("@random_num")
     )
 
     res = client.ft().aggregate(req).rows[0]
@@ -934,8 +825,7 @@ def test_aggregations_groupby(client):
     assert res[3] == "3"  # min(10,8,3)
 
     req = aggregations.AggregateRequest("redis").group_by(
-        "@parent",
-        reducers.max("@random_num"),
+        "@parent", reducers.max("@random_num")
     )
 
     res = client.ft().aggregate(req).rows[0]
@@ -943,8 +833,7 @@ def test_aggregations_groupby(client):
     assert res[3] == "10"  # max(10,8,3)
 
     req = aggregations.AggregateRequest("redis").group_by(
-        "@parent",
-        reducers.avg("@random_num"),
+        "@parent", reducers.avg("@random_num")
     )
 
     res = client.ft().aggregate(req).rows[0]
@@ -953,8 +842,7 @@ def test_aggregations_groupby(client):
     assert res[index + 1] == "7"  # (10+3+8)/3
 
     req = aggregations.AggregateRequest("redis").group_by(
-        "@parent",
-        reducers.stddev("random_num"),
+        "@parent", reducers.stddev("random_num")
     )
 
     res = client.ft().aggregate(req).rows[0]
@@ -962,8 +850,7 @@ def test_aggregations_groupby(client):
     assert res[3] == "3.60555127546"
 
     req = aggregations.AggregateRequest("redis").group_by(
-        "@parent",
-        reducers.quantile("@random_num", 0.5),
+        "@parent", reducers.quantile("@random_num", 0.5)
     )
 
     res = client.ft().aggregate(req).rows[0]
@@ -971,25 +858,22 @@ def test_aggregations_groupby(client):
     assert res[3] == "8"  # median of 3,8,10
 
     req = aggregations.AggregateRequest("redis").group_by(
-        "@parent",
-        reducers.tolist("@title"),
+        "@parent", reducers.tolist("@title")
     )
 
     res = client.ft().aggregate(req).rows[0]
     assert res[1] == "redis"
-    assert res[3] == ["RediSearch", "RedisAI", "RedisJson"]
+    assert set(res[3]) == {"RediSearch", "RedisAI", "RedisJson"}
 
     req = aggregations.AggregateRequest("redis").group_by(
-        "@parent",
-        reducers.first_value("@title").alias("first"),
+        "@parent", reducers.first_value("@title").alias("first")
     )
 
     res = client.ft().aggregate(req).rows[0]
     assert res == ["parent", "redis", "first", "RediSearch"]
 
     req = aggregations.AggregateRequest("redis").group_by(
-        "@parent",
-        reducers.random_sample("@title", 2).alias("random"),
+        "@parent", reducers.random_sample("@title", 2).alias("random")
     )
 
     res = client.ft().aggregate(req).rows[0]
@@ -1001,12 +885,7 @@ def test_aggregations_groupby(client):
 
 @pytest.mark.redismod
 def test_aggregations_sort_by_and_limit(client):
-    client.ft().create_index(
-        (
-            TextField("t1"),
-            TextField("t2"),
-        )
-    )
+    client.ft().create_index((TextField("t1"), TextField("t2")))
 
     client.ft().client.hset("doc1", mapping={"t1": "a", "t2": "b"})
     client.ft().client.hset("doc2", mapping={"t1": "b", "t2": "a"})
@@ -1039,12 +918,7 @@ def test_aggregations_sort_by_and_limit(client):
 
 @pytest.mark.redismod
 def test_aggregations_load(client):
-    client.ft().create_index(
-        (
-            TextField("t1"),
-            TextField("t2"),
-        )
-    )
+    client.ft().create_index((TextField("t1"), TextField("t2")))
 
     client.ft().client.hset("doc1", mapping={"t1": "hello", "t2": "world"})
 
@@ -1093,10 +967,7 @@ def test_aggregations_apply(client):
 @pytest.mark.redismod
 def test_aggregations_filter(client):
     client.ft().create_index(
-        (
-            TextField("name", sortable=True),
-            NumericField("age", sortable=True),
-        )
+        (TextField("name", sortable=True), NumericField("age", sortable=True))
     )
 
     client.ft().client.hset("doc1", mapping={"name": "bar", "age": "25"})
@@ -1161,7 +1032,7 @@ def test_index_definition(client):
 @pytest.mark.redismod
 @pytest.mark.onlynoncluster
 @skip_if_redis_enterprise()
-def testExpire(client):
+def test_expire(client):
     client.ft().create_index((TextField("txt", sortable=True),), temporary=4)
     ttl = client.execute_command("ft.debug", "TTL", "idx")
     assert ttl > 2
@@ -1170,20 +1041,9 @@ def testExpire(client):
         ttl = client.execute_command("ft.debug", "TTL", "idx")
         time.sleep(0.01)
 
-    # add document - should reset the ttl
-    client.ft().add_document("doc", txt="foo bar", text="this is a simple test")
-    ttl = client.execute_command("ft.debug", "TTL", "idx")
-    assert ttl > 2
-    try:
-        while True:
-            ttl = client.execute_command("ft.debug", "TTL", "idx")
-            time.sleep(0.5)
-    except redis.exceptions.ResponseError:
-        assert ttl == 0
-
 
 @pytest.mark.redismod
-def testSkipInitialScan(client):
+def test_skip_initial_scan(client):
     client.hset("doc1", "foo", "bar")
     q = Query("@foo:bar")
 
@@ -1192,23 +1052,23 @@ def testSkipInitialScan(client):
 
 
 @pytest.mark.redismod
-def testSummarizeDisabled_nooffset(client):
+def test_summarize_disabled_nooffset(client):
     client.ft().create_index((TextField("txt"),), no_term_offsets=True)
-    client.ft().add_document("doc1", txt="foo bar")
+    client.hset("doc1", mapping={"txt": "foo bar"})
     with pytest.raises(Exception):
         client.ft().search(Query("foo").summarize(fields=["txt"]))
 
 
 @pytest.mark.redismod
-def testSummarizeDisabled_nohl(client):
+def test_summarize_disabled_nohl(client):
     client.ft().create_index((TextField("txt"),), no_highlight=True)
-    client.ft().add_document("doc1", txt="foo bar")
+    client.hset("doc1", mapping={"txt": "foo bar"})
     with pytest.raises(Exception):
         client.ft().search(Query("foo").summarize(fields=["txt"]))
 
 
 @pytest.mark.redismod
-def testMaxTextFields(client):
+def test_max_text_fields(client):
     # Creating the index definition
     client.ft().create_index((TextField("f0"),))
     for x in range(1, 32):
@@ -1304,6 +1164,31 @@ def test_fields_as_name(client):
     assert "25" == total[0].just_a_number
 
 
+@pytest.mark.redismod
+def test_casesensitive(client):
+    # create index
+    SCHEMA = (TagField("t", case_sensitive=False),)
+    client.ft().create_index(SCHEMA)
+    client.ft().client.hset("1", "t", "HELLO")
+    client.ft().client.hset("2", "t", "hello")
+
+    res = client.ft().search("@t:{HELLO}").docs
+
+    assert 2 == len(res)
+    assert "1" == res[0].id
+    assert "2" == res[1].id
+
+    # create casesensitive index
+    client.ft().dropindex()
+    SCHEMA = (TagField("t", case_sensitive=True),)
+    client.ft().create_index(SCHEMA)
+    waitForIndex(client, getattr(client.ft(), "index_name", "idx"))
+
+    res = client.ft().search("@t:{HELLO}").docs
+    assert 1 == len(res)
+    assert "1" == res[0].id
+
+
 @pytest.mark.redismod
 @skip_ifmodversion_lt("2.2.0", "search")
 def test_search_return_fields(client):
@@ -1316,12 +1201,9 @@ def test_search_return_fields(client):
 
     # create index on
     definition = IndexDefinition(index_type=IndexType.JSON)
-    SCHEMA = (
-        TextField("$.t"),
-        NumericField("$.flt"),
-    )
+    SCHEMA = (TextField("$.t"), NumericField("$.flt"))
     client.ft().create_index(SCHEMA, definition=definition)
-    waitForIndex(client, "idx")
+    waitForIndex(client, getattr(client.ft(), "index_name", "idx"))
 
     total = client.ft().search(Query("*").return_field("$.t", as_field="txt")).docs
     assert 1 == len(total)
@@ -1338,18 +1220,14 @@ def test_search_return_fields(client):
 def test_synupdate(client):
     definition = IndexDefinition(index_type=IndexType.HASH)
     client.ft().create_index(
-        (
-            TextField("title"),
-            TextField("body"),
-        ),
-        definition=definition,
+        (TextField("title"), TextField("body")), definition=definition
     )
 
     client.ft().synupdate("id1", True, "boy", "child", "offspring")
-    client.ft().add_document("doc1", title="he is a baby", body="this is a test")
+    client.hset("doc1", mapping={"title": "he is a baby", "body": "this is a test"})
 
     client.ft().synupdate("id1", True, "baby")
-    client.ft().add_document("doc2", title="he is another baby", body="another test")
+    client.hset("doc2", mapping={"title": "he is another baby", "body": "another test"})
 
     res = client.ft().search(Query("child").expander("SYNONYM"))
     assert res.docs[0].id == "doc2"
@@ -1361,11 +1239,7 @@ def test_synupdate(client):
 def test_syndump(client):
     definition = IndexDefinition(index_type=IndexType.HASH)
     client.ft().create_index(
-        (
-            TextField("title"),
-            TextField("body"),
-        ),
-        definition=definition,
+        (TextField("title"), TextField("body")), definition=definition
     )
 
     client.ft().synupdate("id1", False, "boy", "child", "offspring")
@@ -1461,9 +1335,9 @@ def test_json_with_jsonpath(client):
     assert res.docs[0].id == "doc:1"
     assert res.docs[0].json == '{"prod:name":"RediSearch"}'
 
-    # query for an unsupported field fails
+    # query for an unsupported field
     res = client.ft().search("@name_unsupported:RediSearch")
-    assert res.total == 0
+    assert res.total == 1
 
     # return of a supported field succeeds
     res = client.ft().search(Query("@name:RediSearch").return_field("name"))
@@ -1471,13 +1345,6 @@ def test_json_with_jsonpath(client):
     assert res.docs[0].id == "doc:1"
     assert res.docs[0].name == "RediSearch"
 
-    # return of an unsupported field fails
-    res = client.ft().search(Query("@name:RediSearch").return_field("name_unsupported"))
-    assert res.total == 1
-    assert res.docs[0].id == "doc:1"
-    with pytest.raises(Exception):
-        res.docs[0].name_unsupported
-
 
 @pytest.mark.redismod
 @pytest.mark.onlynoncluster
@@ -1532,6 +1399,30 @@ def test_profile_limited(client):
     assert len(res.docs) == 3  # check also the search result
 
 
+@pytest.mark.redismod
+@skip_ifmodversion_lt("2.4.3", "search")
+def test_profile_query_params(modclient: redis.Redis):
+    modclient.flushdb()
+    modclient.ft().create_index(
+        (
+            VectorField(
+                "v", "HNSW", {"TYPE": "FLOAT32", "DIM": 2, "DISTANCE_METRIC": "L2"}
+            ),
+        )
+    )
+    modclient.hset("a", "v", "aaaaaaaa")
+    modclient.hset("b", "v", "aaaabaaa")
+    modclient.hset("c", "v", "aaaaabaa")
+    query = "*=>[KNN 2 @v $vec]"
+    q = Query(query).return_field("__v_score").sort_by("__v_score", True).dialect(2)
+    res, det = modclient.ft().profile(q, query_params={"vec": "aaaaaaaa"})
+    assert det["Iterators profile"]["Counter"] == 2.0
+    assert det["Iterators profile"]["Type"] == "VECTOR"
+    assert res.total == 2
+    assert "a" == res.docs[0].id
+    assert "0" == res.docs[0].__getattribute__("__v_score")
+
+
 @pytest.mark.redismod
 @skip_ifmodversion_lt("2.4.3", "search")
 def test_vector_field(modclient):
@@ -1575,9 +1466,9 @@ def test_text_params(modclient):
     modclient.flushdb()
     modclient.ft().create_index((TextField("name"),))
 
-    modclient.ft().add_document("doc1", name="Alice")
-    modclient.ft().add_document("doc2", name="Bob")
-    modclient.ft().add_document("doc3", name="Carol")
+    modclient.hset("doc1", mapping={"name": "Alice"})
+    modclient.hset("doc2", mapping={"name": "Bob"})
+    modclient.hset("doc3", mapping={"name": "Carol"})
 
     params_dict = {"name1": "Alice", "name2": "Bob"}
     q = Query("@name:($name1 | $name2 )").dialect(2)
@@ -1593,9 +1484,9 @@ def test_numeric_params(modclient):
     modclient.flushdb()
     modclient.ft().create_index((NumericField("numval"),))
 
-    modclient.ft().add_document("doc1", numval=101)
-    modclient.ft().add_document("doc2", numval=102)
-    modclient.ft().add_document("doc3", numval=103)
+    modclient.hset("doc1", mapping={"numval": 101})
+    modclient.hset("doc2", mapping={"numval": 102})
+    modclient.hset("doc3", mapping={"numval": 103})
 
     params_dict = {"min": 101, "max": 102}
     q = Query("@numval:[$min $max]").dialect(2)
@@ -1612,9 +1503,9 @@ def test_geo_params(modclient):
 
     modclient.flushdb()
     modclient.ft().create_index((GeoField("g")))
-    modclient.ft().add_document("doc1", g="29.69465, 34.95126")
-    modclient.ft().add_document("doc2", g="29.69350, 34.94737")
-    modclient.ft().add_document("doc3", g="29.68746, 34.94882")
+    modclient.hset("doc1", mapping={"g": "29.69465, 34.95126"})
+    modclient.hset("doc2", mapping={"g": "29.69350, 34.94737"})
+    modclient.hset("doc3", mapping={"g": "29.68746, 34.94882"})
 
     params_dict = {"lat": "34.95126", "lon": "29.69465", "radius": 1000, "units": "km"}
     q = Query("@g:[$lon $lat $radius $units]").dialect(2)
@@ -1630,16 +1521,15 @@ def test_geo_params(modclient):
 def test_search_commands_in_pipeline(client):
     p = client.ft().pipeline()
     p.create_index((TextField("txt"),))
-    p.add_document("doc1", payload="foo baz", txt="foo bar")
-    p.add_document("doc2", txt="foo bar")
+    p.hset("doc1", mapping={"txt": "foo bar"})
+    p.hset("doc2", mapping={"txt": "foo bar"})
     q = Query("foo bar").with_payloads()
     p.search(q)
     res = p.execute()
-    assert res[:3] == ["OK", "OK", "OK"]
+    assert res[:3] == ["OK", True, True]
     assert 2 == res[3][0]
     assert "doc1" == res[3][1]
     assert "doc2" == res[3][4]
-    assert "foo baz" == res[3][2]
     assert res[3][5] is None
     assert res[3][3] == res[3][6] == ["txt", "foo bar"]
 
@@ -1687,3 +1577,41 @@ def test_dialect(modclient: redis.Redis):
     with pytest.raises(redis.ResponseError) as err:
         modclient.ft().explain(Query("@title:(@num:[0 10])").dialect(2))
     assert "Syntax error" in str(err)
+
+
+@pytest.mark.redismod
+def test_expire_while_search(modclient: redis.Redis):
+    modclient.ft().create_index((TextField("txt"),))
+    modclient.hset("hset:1", "txt", "a")
+    modclient.hset("hset:2", "txt", "b")
+    modclient.hset("hset:3", "txt", "c")
+    assert 3 == modclient.ft().search(Query("*")).total
+    modclient.pexpire("hset:2", 300)
+    for _ in range(500):
+        modclient.ft().search(Query("*")).docs[1]
+    time.sleep(1)
+    assert 2 == modclient.ft().search(Query("*")).total
+
+
+@pytest.mark.redismod
+@pytest.mark.experimental
+def test_withsuffixtrie(modclient: redis.Redis):
+    # create index
+    assert modclient.ft().create_index((TextField("txt"),))
+    waitForIndex(modclient, getattr(modclient.ft(), "index_name", "idx"))
+    info = modclient.ft().info()
+    assert "WITHSUFFIXTRIE" not in info["attributes"][0]
+    assert modclient.ft().dropindex("idx")
+
+    # create withsuffixtrie index (text fiels)
+    assert modclient.ft().create_index((TextField("t", withsuffixtrie=True)))
+    waitForIndex(modclient, getattr(modclient.ft(), "index_name", "idx"))
+    info = modclient.ft().info()
+    assert "WITHSUFFIXTRIE" in info["attributes"][0]
+    assert modclient.ft().dropindex("idx")
+
+    # create withsuffixtrie index (tag field)
+    assert modclient.ft().create_index((TagField("t", withsuffixtrie=True)))
+    waitForIndex(modclient, getattr(modclient.ft(), "index_name", "idx"))
+    info = modclient.ft().info()
+    assert "WITHSUFFIXTRIE" in info["attributes"][0]
